==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/BREAKUPKITPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour BREAKUPKITPARTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="BREAKUPKITPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINENUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BREAKUPKITPARTID_Type", propOrder = {
    "transactionlinenum",
    "lotid"
})
public class BREAKUPKITPARTID_Type {

    @XmlElement(name = "TRANSACTIONLINENUM")
    protected long transactionlinenum;
    @XmlElement(name = "LOTID", required = true)
    protected LOTID_Type lotid;

    /**
     * Obtient la valeur de la propriété transactionlinenum.
     * 
     */
    public long getTRANSACTIONLINENUM() {
        return transactionlinenum;
    }

    /**
     * Définit la valeur de la propriété transactionlinenum.
     * 
     */
    public void setTRANSACTIONLINENUM(long value) {
        this.transactionlinenum = value;
    }

    /**
     * Obtient la valeur de la propriété lotid.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Définit la valeur de la propriété lotid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/BREAKUPKITPARTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BREAKUPKITPARTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BREAKUPKITPARTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINENUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BREAKUPKITPARTID_Type", propOrder = {
    "transactionlinenum",
    "lotid"
})
public class BREAKUPKITPARTID_Type {

    @XmlElement(name = "TRANSACTIONLINENUM")
    protected long transactionlinenum;
    @XmlElement(name = "LOTID", required = true)
    protected LOTID_Type lotid;

    /**
     * Gets the value of the transactionlinenum property.
     * 
     */
    public long getTRANSACTIONLINENUM() {
        return transactionlinenum;
    }

    /**
     * Sets the value of the transactionlinenum property.
     * 
     */
    public void setTRANSACTIONLINENUM(long value) {
        this.transactionlinenum = value;
    }

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

}
